|PypiVersion| |Doc badge| |Pypi|

===============
Django-Leonardo
===============

This is a stable for daily use in development.

A collection of awesome Django libraries, resources and shiny things.
Full featured framework for building everything based on Django, FeinCMS, Horizon, Oscar and tons of another apps.

**Don't waste your time searching stable solution for daily problems.**

.. toctree::
   :maxdepth: 2

   overview/index

Installation
============

.. toctree::
   :maxdepth: 2

   install/intro
   install/development
   install/production
   install/bootstrap
   install/salt

Configuration
=============

.. toctree::
   :maxdepth: 2

   config/config
   config/live
   config/media
   config/migrations
   config/languages
   config/search
   config/themes

Extend
======

.. toctree::
   :maxdepth: 2

   extends/new_site
   extends/new_theme
   extends/new_module
   extends/conf_reference

Components
==========

.. toctree::
   :maxdepth: 2

   components/thumbnails
   components/live_settings
   components/messages
   components/modals

Contribute
==========

Feel free and contribute to Leonardo CMS ! Follow next steps

.. toctree::
   :maxdepth: 2

   overview/contrib
   install/development

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |Doc badge| image:: https://readthedocs.org/projects/django-leonardo/badge/?version=stable
.. |Pypi| image:: https://pypip.in/d/django-leonardo/badge.svg?style=flat
.. |PypiVersion| image:: https://pypip.in/version/django-leonardo/badge.svg?style=flat
.. [Documentation] http://django-leonardo.readthedocs.org